@@ -55,10 +55,10 @@
 /* VOID:INT,STRING (./anjuta-marshal.list:26) */
 void
 anjuta_cclosure_marshal_VOID__INT_STRING (GClosure     *closure,
-                                          GValue       *return_value,
+                                          GValue       *return_value G_GNUC_UNUSED,
                                           guint         n_param_values,
                                           const GValue *param_values,
-                                          gpointer      invocation_hint,
+                                          gpointer      invocation_hint G_GNUC_UNUSED,
                                           gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_STRING) (gpointer     data1,
@@ -92,10 +92,10 @@ anjuta_cclosure_marshal_VOID__INT_STRING (GClosure     *closure,
 /* VOID:INT,OBJECT (./anjuta-marshal.list:27) */
 void
 anjuta_cclosure_marshal_VOID__INT_OBJECT (GClosure     *closure,
-                                          GValue       *return_value,
+                                          GValue       *return_value G_GNUC_UNUSED,
                                           guint         n_param_values,
                                           const GValue *param_values,
-                                          gpointer      invocation_hint,
+                                          gpointer      invocation_hint G_GNUC_UNUSED,
                                           gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_OBJECT) (gpointer     data1,
@@ -129,10 +129,10 @@ anjuta_cclosure_marshal_VOID__INT_OBJECT (GClosure     *closure,
 /* VOID:INT,INT,ULONG (./anjuta-marshal.list:28) */
 void
 anjuta_cclosure_marshal_VOID__INT_INT_ULONG (GClosure     *closure,
-                                             GValue       *return_value,
+                                             GValue       *return_value G_GNUC_UNUSED,
                                              guint         n_param_values,
                                              const GValue *param_values,
-                                             gpointer      invocation_hint,
+                                             gpointer      invocation_hint G_GNUC_UNUSED,
                                              gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT_INT_ULONG) (gpointer     data1,
@@ -168,10 +168,10 @@ anjuta_cclosure_marshal_VOID__INT_INT_ULONG (GClosure     *closure,
 /* VOID:STRING,POINTER (./anjuta-marshal.list:29) */
 void
 anjuta_cclosure_marshal_VOID__STRING_POINTER (GClosure     *closure,
-                                              GValue       *return_value,
+                                              GValue       *return_value G_GNUC_UNUSED,
                                               guint         n_param_values,
                                               const GValue *param_values,
-                                              gpointer      invocation_hint,
+                                              gpointer      invocation_hint G_GNUC_UNUSED,
                                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_POINTER) (gpointer     data1,
@@ -207,10 +207,10 @@ anjuta_cclosure_marshal_VOID__STRING_POINTER (GClosure     *closure,
 /* VOID:STRING,INT (./anjuta-marshal.list:31) */
 void
 anjuta_cclosure_marshal_VOID__STRING_INT (GClosure     *closure,
-                                          GValue       *return_value,
+                                          GValue       *return_value G_GNUC_UNUSED,
                                           guint         n_param_values,
                                           const GValue *param_values,
-                                          gpointer      invocation_hint,
+                                          gpointer      invocation_hint G_GNUC_UNUSED,
                                           gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_INT) (gpointer     data1,
@@ -244,10 +244,10 @@ anjuta_cclosure_marshal_VOID__STRING_INT (GClosure     *closure,
 /* VOID:STRING,INT,STRING (./anjuta-marshal.list:32) */
 void
 anjuta_cclosure_marshal_VOID__STRING_INT_STRING (GClosure     *closure,
-                                                 GValue       *return_value,
+                                                 GValue       *return_value G_GNUC_UNUSED,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
-                                                 gpointer      invocation_hint,
+                                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_INT_STRING) (gpointer     data1,
@@ -283,10 +283,10 @@ anjuta_cclosure_marshal_VOID__STRING_INT_STRING (GClosure     *closure,
 /* VOID:STRING,BOXED (./anjuta-marshal.list:33) */
 void
 anjuta_cclosure_marshal_VOID__STRING_BOXED (GClosure     *closure,
-                                            GValue       *return_value,
+                                            GValue       *return_value G_GNUC_UNUSED,
                                             guint         n_param_values,
                                             const GValue *param_values,
-                                            gpointer      invocation_hint,
+                                            gpointer      invocation_hint G_GNUC_UNUSED,
                                             gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_BOXED) (gpointer     data1,
@@ -324,10 +324,10 @@ anjuta_cclosure_marshal_VOID__STRING_BOXED (GClosure     *closure,
 /* VOID:BOXED,ENUM (./anjuta-marshal.list:36) */
 void
 anjuta_cclosure_marshal_VOID__BOXED_ENUM (GClosure     *closure,
-                                          GValue       *return_value,
+                                          GValue       *return_value G_GNUC_UNUSED,
                                           guint         n_param_values,
                                           const GValue *param_values,
-                                          gpointer      invocation_hint,
+                                          gpointer      invocation_hint G_GNUC_UNUSED,
                                           gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOXED_ENUM) (gpointer     data1,
@@ -361,10 +361,10 @@ anjuta_cclosure_marshal_VOID__BOXED_ENUM (GClosure     *closure,
 /* VOID:POINTER,OBJECT (./anjuta-marshal.list:37) */
 void
 anjuta_cclosure_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
-                                              GValue       *return_value,
+                                              GValue       *return_value G_GNUC_UNUSED,
                                               guint         n_param_values,
                                               const GValue *param_values,
-                                              gpointer      invocation_hint,
+                                              gpointer      invocation_hint G_GNUC_UNUSED,
                                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER_OBJECT) (gpointer     data1,
