@@ -139,6 +139,18 @@ typedef struct
 	gint file_saved;
 } BuildContext;
 
+/* Build function type */
+typedef BuildContext* (*BuildFunc) (BasicAutotoolsPlugin *plugin, const gchar *name,
+                                    IAnjutaBuilderCallback callback, gpointer user_data,
+                                    GError **err);
+
+typedef struct
+{
+	gchar *args;
+	gchar *name;
+	BuildFunc func;
+} BuildConfigureAndBuild;
+
 /* Declarations */
 static void update_project_ui (BasicAutotoolsPlugin *bb_plugin);
 static void update_configuration_menu (BasicAutotoolsPlugin *plugin);
@@ -174,6 +186,109 @@ static void on_root_check_toggled(GtkWidget* toggle_button, GtkWidget* entry)
 			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(toggle_button)));
 }
 
+static gboolean
+directory_has_makefile_am (BasicAutotoolsPlugin *bb_plugin, const char *dirname )
+{
+	gchar *configure;
+	gchar *makefile_am;
+	gboolean makefile_am_exists;
+
+	/* We need configure.ac or configure.in too */	
+	if (bb_plugin->project_root_dir == NULL) return FALSE;
+	
+	configure = g_build_filename (bb_plugin->project_root_dir, "configure.ac", NULL);
+	if (!g_file_test (configure, G_FILE_TEST_EXISTS))
+	{
+		g_free (configure);
+		configure = g_build_filename (bb_plugin->project_root_dir, "configure.in", NULL);
+		if (!g_file_test (configure, G_FILE_TEST_EXISTS))
+		{
+			g_free (configure);
+
+			return FALSE;
+		}
+	}
+	g_free (configure);
+
+	/* Check for Makefile.am */
+	makefile_am = g_build_filename (dirname, "Makefile.am", NULL);
+	makefile_am_exists = g_file_test (makefile_am, G_FILE_TEST_EXISTS);
+	g_free (makefile_am);
+
+	return makefile_am_exists;
+}
+
+static gboolean
+directory_has_makefile (const gchar *dirname)
+{
+	gchar *makefile;
+	gboolean makefile_exists;
+	
+	makefile_exists = TRUE;	
+	makefile = g_build_filename (dirname, "Makefile", NULL);
+	if (!g_file_test (makefile, G_FILE_TEST_EXISTS))
+	{
+		g_free (makefile);
+		makefile = g_build_filename (dirname, "makefile", NULL);
+		if (!g_file_test (makefile, G_FILE_TEST_EXISTS))
+		{
+			g_free (makefile);
+			makefile = g_build_filename (dirname, "MAKEFILE", NULL);
+			if (!g_file_test (makefile, G_FILE_TEST_EXISTS))
+			{
+				makefile_exists = FALSE;
+			}
+		}
+	}
+	g_free (makefile);
+	return makefile_exists;
+}
+
+static gboolean
+directory_has_file (const gchar *dirname, const gchar *filename)
+{
+	gchar *filepath;
+	gboolean exists;
+	
+	exists = TRUE;	
+	filepath = g_build_filename (dirname, filename, NULL);
+	if (!g_file_test (filepath, G_FILE_TEST_EXISTS))
+		exists = FALSE;
+	
+	g_free (filepath);
+	return exists;
+}
+
+static gchar*
+escape_label (const gchar *str)
+{
+	GString *ret;
+	const gchar *iter;
+	
+	ret = g_string_new ("");
+	iter = str;
+	while (*iter != '\0')
+	{
+		if (*iter == '_')
+		{
+			ret = g_string_append (ret, "__");
+			iter++;
+		}
+		else
+		{
+			const gchar *start;
+			const gchar *end;
+			
+			start = iter;
+			iter = g_utf8_next_char (iter);
+			end = iter;
+			
+			ret = g_string_append_len (ret, start, end - start);
+		}
+	}
+	return g_string_free (ret, FALSE);
+}
+
 /* Indicator locations reported by the build */
 
 static BuildIndicatorLocation*
@@ -622,8 +737,8 @@ parse_error_line (const gchar * line, gchar ** filename, int *lineno)
 	}
 
       down:
-	i = strlen (line) - 1;
-	while (isspace (line[i]) == FALSE)
+	i = strlen (line);
+	do
 	{
 		i--;
 		if (i < 0)
@@ -632,7 +747,7 @@ parse_error_line (const gchar * line, gchar ** filename, int *lineno)
 			*lineno = 0;
 			return FALSE;
 		}
-	}
+	} while (isspace (line[i]) == FALSE);
 	k = i++;
 	while (line[i++] != ':')
 	{
@@ -781,11 +896,17 @@ on_build_mesg_format (IAnjutaMessageView *view, const gchar *one_line,
 			type = IANJUTA_MESSAGE_VIEW_TYPE_WARNING;
 			indicator = IANJUTA_INDICABLE_WARNING;
 		}
-		else
+		else if ((strstr (line, "error:") != NULL) ||
+		          (strstr (line, _("error:")) != NULL))
 		{
 			type = IANJUTA_MESSAGE_VIEW_TYPE_ERROR;
 			indicator = IANJUTA_INDICABLE_CRITICAL;
 		}
+		else
+		{
+			type = IANJUTA_MESSAGE_VIEW_TYPE_NORMAL;
+			indicator = IANJUTA_INDICABLE_IMPORTANT;
+		}
 		
 		mid_str = strstr (line, dummy_fn);
 		DEBUG_PRINT ("mid_str = %s, line = %s", mid_str, line);
@@ -1345,7 +1466,7 @@ build_build_file_or_dir (BasicAutotoolsPlugin *plugin, const gchar *name,
 										   "%s %s",
 										   CHOOSE_COMMAND (plugin, BUILD),
 										   target ? target : "");
-	if (callback) build_program_set_callback (prog, callback, user_data);
+	build_program_set_callback (prog, callback, user_data);
 	
 	context = build_save_and_execute_command (plugin, prog, TRUE, err);
 	g_free (target);
@@ -1406,18 +1527,22 @@ get_root_install_command(BasicAutotoolsPlugin *bplugin)
 
 static BuildContext*
 build_install_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname,
+                   IAnjutaBuilderCallback callback, gpointer user_data,
 				   GError **err)
 {
 	BuildContext *context;
 	gchar* root = get_root_install_command(plugin);
 	gchar *build_dir = build_dir_from_source (plugin, dirname);
+	BuildProgram *prog;
 
-	context = build_save_and_execute_command (plugin,
-									 build_program_new_with_command (build_dir,
-																	 "%s %s",
-																	 root,
-																	 CHOOSE_COMMAND (plugin, INSTALL)),
-									 TRUE, err);
+	prog = build_program_new_with_command (build_dir,
+	                                       "%s %s",
+	                                       root,
+	                                       CHOOSE_COMMAND (plugin, INSTALL)),
+	build_program_set_callback (prog, callback, user_data);	
+	
+	context = build_save_and_execute_command (plugin, prog, TRUE, err);
+	
 	g_free (build_dir);
 	g_free(root);
 	
@@ -1576,31 +1701,47 @@ build_project_configured (GObject *sender,
 							GError *error,
 							gpointer user_data)
 {
-	if (error != NULL) return;
+	BuildConfigureAndBuild *pack = (BuildConfigureAndBuild *)user_data;
+	
+	if (error == NULL)
+	{
+		BuildContext *context = (BuildContext *)handle;
+		BasicAutotoolsPlugin *plugin = (BasicAutotoolsPlugin *)(context == NULL ? (void *)sender : (void *)context->plugin);
+		GValue *value;
+		gchar *uri;
+	
+		/* FIXME: check if build directory correspond, configuration could have changed */
+		value = g_new0 (GValue, 1);
+		g_value_init (value, G_TYPE_STRING);
+	
+		uri = build_configuration_list_get_build_uri (plugin->configurations, build_configuration_list_get_selected (plugin->configurations));
+		g_value_set_string (value, uri);
+		g_free (uri);
+	
+		anjuta_shell_add_value (ANJUTA_PLUGIN (plugin)->shell, IANJUTA_BUILDER_ROOT_URI, value, NULL);
+	
+		update_configuration_menu (plugin);
 
-	BuildContext *context = (BuildContext *)handle;
-	BasicAutotoolsPlugin *plugin = (BasicAutotoolsPlugin *)(context == NULL ? (void *)sender : (void *)context->plugin);
-	GValue *value;
-	gchar *uri;
-	
-	/* FIXME: check if build directory correspond, configuration could have changed */
-	value = g_new0 (GValue, 1);
-	g_value_init (value, G_TYPE_STRING);
-	
-	uri = build_configuration_list_get_build_uri (plugin->configurations, build_configuration_list_get_selected (plugin->configurations));
-	g_value_set_string (value, uri);
-	g_free (uri);
-	
-	anjuta_shell_add_value (ANJUTA_PLUGIN (plugin)->shell, IANJUTA_BUILDER_ROOT_URI, value, NULL);
-	
-	update_configuration_menu (plugin);
+		/* Call build function if necessary */
+		if ((pack) && (pack->func != NULL)) pack->func (plugin, pack->name, NULL, NULL, NULL);
+	}
+
+	if (pack)
+	{
+		g_free (pack->args);
+		g_free (pack->name);
+		g_free (pack);
+	}
 }
 
 static BuildContext*
-build_configure_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const gchar *args)
+build_configure_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const gchar *args,
+                     BuildFunc func, const gchar *name)
 {
 	BuildContext *context;
 	BuildProgram *prog;
+	BuildConfigureAndBuild *pack = g_new(BuildConfigureAndBuild, 1);
+
 	
 	prog = build_program_new_with_command (dirname,
 										   "%s%s%s %s",
@@ -1608,7 +1749,10 @@ build_configure_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const g
 										   G_DIR_SEPARATOR_S,
 										   CHOOSE_COMMAND (plugin, CONFIGURE),
 										   args);
-	build_program_set_callback (prog, build_project_configured, NULL);
+	pack->args = NULL;
+	pack->func = func;
+	pack->name = g_strdup (name);
+	build_program_set_callback (prog, build_project_configured, pack);
 	
 	context = build_save_and_execute_command (plugin, prog, TRUE, NULL);
 	
@@ -1623,23 +1767,29 @@ build_configure_after_autogen (GObject *sender,
 							   GError *error,
 							   gpointer user_data)
 {
+	BuildConfigureAndBuild *pack = (BuildConfigureAndBuild *)user_data;
+	
 	if (error == NULL)
 	{
 		BuildContext *context = (BuildContext *)handle;
 		BasicAutotoolsPlugin *plugin = (BasicAutotoolsPlugin *)context->plugin;
 		struct stat conf_stat, log_stat;
 		gchar *filename;
+		gboolean has_configure;
 		
 		filename = g_build_filename (plugin->project_root_dir, "configure", NULL);
-		if (stat (filename, &conf_stat) != 0)
+		has_configure = stat (filename, &conf_stat) == 0;
+		g_free (filename);
+			
+		if (has_configure)
 		{
-			anjuta_util_dialog_error (GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell), _("Can not configure project: Missing configure script in %s."), plugin->project_root_dir);
-		}
-		else
-		{
-			g_free (filename);
+			gboolean older;
+			
 			filename = g_build_filename (context->program->work_dir, "config.log", NULL);
-			if ((stat (filename, &log_stat) != 0) || (log_stat.st_mtime < conf_stat.st_mtime))
+			older =(stat (filename, &log_stat) != 0) || (log_stat.st_mtime < conf_stat.st_mtime);
+			g_free (filename);
+			
+			if (older)
 			{
 				/* configure has not be run, run it */
 				BuildProgram *prog;
@@ -1649,23 +1799,38 @@ build_configure_after_autogen (GObject *sender,
 													   plugin->project_root_dir,
 													   G_DIR_SEPARATOR_S,
 													   CHOOSE_COMMAND (plugin, CONFIGURE),
-													   (gchar *)user_data);
-				build_program_set_callback (prog, build_project_configured, NULL);
+													   pack != NULL ? pack->args : NULL);
+				build_program_set_callback (prog, build_project_configured, pack);
 		
 				build_set_command_in_context (context, prog);
 				build_execute_command_in_context (context, NULL);
 			}
+			else
+			{
+				/* run next command if needed */
+				build_project_configured (sender, handle, NULL, pack);
+			}
+			
+			return;
 		}
-		g_free (filename);
+		anjuta_util_dialog_error (GTK_WINDOW (ANJUTA_PLUGIN (plugin)->shell), _("Can not configure project: Missing configure script in %s."), plugin->project_root_dir);
+	}
+
+	if (pack)
+	{
+		g_free (pack->args);
+		g_free (pack->name);
+		g_free (pack);
 	}
-	g_free (user_data);
 }
 
 static BuildContext*
-build_generate_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const gchar *args)
+build_generate_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const gchar *args,
+                    BuildFunc func, const gchar *name)
 {
 	BuildContext *context;
 	BuildProgram *prog;
+	BuildConfigureAndBuild *pack = g_new (BuildConfigureAndBuild, 1);
 	
 	if (directory_has_file (plugin->project_root_dir, "autogen.sh"))
 	{
@@ -1683,48 +1848,18 @@ build_generate_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const gc
 											   CHOOSE_COMMAND (plugin, AUTORECONF),
 											   args);
 	}
-	build_program_set_callback (prog, build_configure_after_autogen, g_strdup (args));
+	pack->args = g_strdup (args);
+	pack->func = func;
+	pack->name = g_strdup (name);
+	build_program_set_callback (prog, build_configure_after_autogen, pack);
 	
 	context = build_save_and_execute_command (plugin, prog, TRUE, NULL);
 	
 	return context;
 }
 
-
-
-/* User actions
- *---------------------------------------------------------------------------*/
-
-/* Main menu */
 static void
-on_build_project (GtkAction *action, BasicAutotoolsPlugin *plugin)
-{
-	if (plugin->project_root_dir)
-	{
-		build_build_file_or_dir (plugin, plugin->project_root_dir, NULL, NULL, NULL);
-	}
-}
-
-static void
-on_install_project (GtkAction *action, BasicAutotoolsPlugin *plugin)
-{
-	if (plugin->project_root_dir)
-	{
-		build_install_dir (plugin, plugin->project_root_dir, NULL);
-	}
-}
-
-static void
-on_clean_project (GtkAction *action, BasicAutotoolsPlugin *plugin)
-{
-	if (plugin->project_root_dir)
-	{
-		build_clean_dir (plugin, plugin->project_root_dir, NULL);
-	}
-}
-
-static void
-on_configure_project (GtkAction *action, BasicAutotoolsPlugin *plugin)
+build_configure_dialog (BasicAutotoolsPlugin *plugin, BuildFunc func, const gchar *name)
 {
 	GtkWindow *parent;
 	gboolean run_autogen = FALSE;
@@ -1757,20 +1892,101 @@ on_configure_project (GtkAction *action, BasicAutotoolsPlugin *plugin)
 		
 		if (run_autogen)
 		{
-			build_generate_dir (plugin, build_dir, args);
+			build_generate_dir (plugin, build_dir, args, func, name);
 		}
 		else
 		{
-			build_configure_dir (plugin, build_dir, args);
+			build_configure_dir (plugin, build_dir, args, func, name);
 		}
 		g_free (build_dir);
 	}
+	
+}
+
+/* Run configure if needed and then the build command */
+static void
+build_configure_and_build (BasicAutotoolsPlugin *plugin, BuildFunc func, const gchar *name)
+{
+	const gchar *src_dir;
+	gchar *dir = NULL;
+	gchar *build_dir;
+	gboolean has_makefile;
+
+	/* Find source directory */
+	if (name == NULL)
+	{
+		/* Could be NULL for global project command */
+		src_dir = plugin->project_root_dir;
+	}
+	else if (g_file_test (name, G_FILE_TEST_IS_DIR))
+	{
+		src_dir = name;
+	}
+	else
+	{
+		dir = g_path_get_dirname (name);
+		src_dir = dir;
+	}
+
+	/* Get build directory and check for makefiles */
+	build_dir = build_dir_from_source (plugin, src_dir);
+	has_makefile = directory_has_makefile (build_dir);
+	g_free (build_dir);
+
+	if (!has_makefile)
+	{
+		/* Run configure first */
+		build_configure_dialog (plugin, func, name);
+	}
+	else
+	{
+		/* Some build functions have less arguments but
+		 * it is not a problem in C */
+		func (plugin, name, NULL, NULL, NULL);
+	}
+}
+
+/* User actions
+ *---------------------------------------------------------------------------*/
+
+/* Main menu */
+static void
+on_build_project (GtkAction *action, BasicAutotoolsPlugin *plugin)
+{
+	if (plugin->project_root_dir)
+	{
+		build_configure_and_build (plugin, build_build_file_or_dir, plugin->project_root_dir);
+	}
+}
+
+static void
+on_install_project (GtkAction *action, BasicAutotoolsPlugin *plugin)
+{
+	if (plugin->project_root_dir)
+	{
+		build_configure_and_build (plugin, build_install_dir,  plugin->project_root_dir);
+	}
+}
+
+static void
+on_clean_project (GtkAction *action, BasicAutotoolsPlugin *plugin)
+{
+	if (plugin->project_root_dir)
+	{
+		build_clean_dir (plugin, plugin->project_root_dir, NULL);
+	}
+}
+
+static void
+on_configure_project (GtkAction *action, BasicAutotoolsPlugin *plugin)
+{
+	build_configure_dialog (plugin, NULL, NULL);
 }
 
 static void
 on_build_tarball (GtkAction *action, BasicAutotoolsPlugin *plugin)
 {
-	build_tarball (plugin);
+	build_configure_and_build (plugin, (BuildFunc) build_tarball, NULL);	
 }
 
 static void
@@ -1779,8 +1995,8 @@ on_build_module (GtkAction *action, BasicAutotoolsPlugin *plugin)
 	if (plugin->current_editor_filename)
 	{
 		gchar *dirname = g_path_get_dirname (plugin->current_editor_filename);
-		
-		build_build_file_or_dir (plugin, dirname, NULL, NULL, NULL);
+
+		build_configure_and_build (plugin, build_build_file_or_dir, dirname);
 		
 		g_free (dirname);
 	}
@@ -1793,7 +2009,7 @@ on_install_module (GtkAction *action, BasicAutotoolsPlugin *plugin)
 	{
 		gchar *dirname = g_path_get_dirname (plugin->current_editor_filename);
 		
-		build_install_dir (plugin, dirname, NULL);
+		build_configure_and_build (plugin, build_install_dir,  dirname);
 		
 		g_free (dirname);
 	}
@@ -1817,7 +2033,7 @@ on_compile_file (GtkAction *action, BasicAutotoolsPlugin *plugin)
 {
 	if (plugin->current_editor_filename)
 	{
-		build_compile_file (plugin, plugin->current_editor_filename);
+		build_configure_and_build (plugin, (BuildFunc) build_compile_file, plugin->current_editor_filename);
 	}
 }
 
@@ -1860,7 +2076,7 @@ fm_compile (GtkAction *action, BasicAutotoolsPlugin *plugin)
 
 	if (plugin->fm_current_filename)
 	{
-		build_compile_file (plugin, plugin->fm_current_filename);
+		build_configure_and_build (plugin, (BuildFunc) build_compile_file, plugin->fm_current_filename);
 	}
 }
 
@@ -1875,8 +2091,8 @@ fm_build (GtkAction *action, BasicAutotoolsPlugin *plugin)
 		dir = g_strdup (plugin->fm_current_filename);
 	else
 		dir = g_path_get_dirname (plugin->fm_current_filename);
-	
-	build_build_file_or_dir (plugin, dir, NULL, NULL, NULL);
+
+	build_configure_and_build (plugin, build_build_file_or_dir, dir);
 	
 	g_free (dir);
 }
@@ -1893,7 +2109,7 @@ fm_install (GtkAction *action, BasicAutotoolsPlugin *plugin)
 	else
 		dir = g_path_get_dirname (plugin->fm_current_filename);
 	
-	build_install_dir (plugin, dir, NULL);
+	build_configure_and_build (plugin, build_install_dir,  dir);
 	
 	g_free (dir);
 }
@@ -1923,7 +2139,7 @@ pm_compile (GtkAction *action, BasicAutotoolsPlugin *plugin)
 
 	if (plugin->pm_current_filename)
 	{
-		build_compile_file (plugin, plugin->pm_current_filename);
+		build_configure_and_build (plugin, (BuildFunc) build_compile_file, plugin->pm_current_filename);
 	}
 }
 
@@ -1939,7 +2155,7 @@ pm_build (GtkAction *action, BasicAutotoolsPlugin *plugin)
 	else
 		dir = g_path_get_dirname (plugin->pm_current_filename);
 
-	build_build_file_or_dir (plugin, dir, NULL, NULL, NULL);
+	build_configure_and_build (plugin, build_build_file_or_dir, dir);
 
 	g_free (dir);
 }
@@ -1956,7 +2172,7 @@ pm_install (GtkAction *action, BasicAutotoolsPlugin *plugin)
 	else
 		dir = g_path_get_dirname (plugin->pm_current_filename);
 	
-	build_install_dir (plugin, dir, NULL);
+	build_configure_and_build (plugin, build_install_dir,  dir);
 	
 	g_free (dir);
 }
@@ -2152,77 +2368,6 @@ static GtkActionEntry build_popup_actions[] =
 	}
 };
 
-static gboolean
-directory_has_makefile (const gchar *dirname)
-{
-	gchar *makefile;
-	gboolean makefile_exists;
-	
-	makefile_exists = TRUE;	
-	makefile = g_build_filename (dirname, "Makefile", NULL);
-	if (!g_file_test (makefile, G_FILE_TEST_EXISTS))
-	{
-		g_free (makefile);
-		makefile = g_build_filename (dirname, "makefile", NULL);
-		if (!g_file_test (makefile, G_FILE_TEST_EXISTS))
-		{
-			g_free (makefile);
-			makefile = g_build_filename (dirname, "MAKEFILE", NULL);
-			if (!g_file_test (makefile, G_FILE_TEST_EXISTS))
-			{
-				makefile_exists = FALSE;
-			}
-		}
-	}
-	g_free (makefile);
-	return makefile_exists;
-}
-
-static gboolean
-directory_has_file (const gchar *dirname, const gchar *filename)
-{
-	gchar *filepath;
-	gboolean exists;
-	
-	exists = TRUE;	
-	filepath = g_build_filename (dirname, filename, NULL);
-	if (!g_file_test (filepath, G_FILE_TEST_EXISTS))
-		exists = FALSE;
-	
-	g_free (filepath);
-	return exists;
-}
-
-static gchar*
-escape_label (const gchar *str)
-{
-	GString *ret;
-	const gchar *iter;
-	
-	ret = g_string_new ("");
-	iter = str;
-	while (*iter != '\0')
-	{
-		if (*iter == '_')
-		{
-			ret = g_string_append (ret, "__");
-			iter++;
-		}
-		else
-		{
-			const gchar *start;
-			const gchar *end;
-			
-			start = iter;
-			iter = g_utf8_next_char (iter);
-			end = iter;
-			
-			ret = g_string_append_len (ret, start, end - start);
-		}
-	}
-	return g_string_free (ret, FALSE);
-}
-
 static void
 update_module_ui (BasicAutotoolsPlugin *bb_plugin)
 {
@@ -2249,7 +2394,7 @@ update_module_ui (BasicAutotoolsPlugin *bb_plugin)
 		
 		module = escape_label (g_path_get_basename (dirname));
 		filename = escape_label (g_path_get_basename (bb_plugin->current_editor_filename));
-		has_makefile = directory_has_makefile (build_dirname);
+		has_makefile = directory_has_makefile (build_dirname) || directory_has_makefile_am (bb_plugin, build_dirname);
 		g_free (build_dirname);
 		g_free (dirname);
 	}
@@ -2298,7 +2443,7 @@ update_project_ui (BasicAutotoolsPlugin *bb_plugin)
 	DEBUG_PRINT ("%s", "Updating project UI");
 	
 	has_project = bb_plugin->project_root_dir != NULL;
-	has_makefile = has_project && directory_has_makefile (bb_plugin->project_build_dir);
+	has_makefile = has_project && (directory_has_makefile (bb_plugin->project_build_dir) || directory_has_makefile_am (bb_plugin, bb_plugin->project_build_dir));
 
 	ui = anjuta_shell_get_ui (ANJUTA_PLUGIN (bb_plugin)->shell, NULL);
 	action = anjuta_ui_get_action (ui, "ActionGroupBuild",
@@ -2378,6 +2523,15 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 		name = build_configuration_get_name (cfg);
 		anjuta_session_set_string (session, "Build", "Selected Configuration", name);
 	}
+	for (cfg = build_configuration_list_get_first (plugin->configurations); cfg != NULL; cfg = build_configuration_next (cfg))
+	{
+		gchar *key = g_strconcat("BuildArgs/", build_configuration_get_name (cfg), NULL);
+
+		anjuta_session_set_string (session, "Build",
+			       key,
+			       build_configuration_get_args(cfg));
+		g_free (key);
+	}
 }
 
 static void
@@ -2386,7 +2540,8 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
 {
 	GList *configurations;
 	gchar *selected;
-				
+	BuildConfiguration *cfg;
+
 	if (phase != ANJUTA_SESSION_PHASE_NORMAL)
 		return;
 	
@@ -2401,6 +2556,19 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
 	build_configuration_list_select (plugin->configurations, selected);
 	g_free (selected);
 
+	for (cfg = build_configuration_list_get_first (plugin->configurations); cfg != NULL; cfg = build_configuration_next (cfg))
+	{
+		gchar *key = g_strconcat("BuildArgs/", build_configuration_get_name (cfg), NULL);
+		gchar *args = anjuta_session_get_string (session, "Build",
+				key);
+		g_free (key);
+		if (args != NULL)
+		{
+			build_configuration_set_args (cfg, args);
+			g_free (args);
+		}
+	}
+
 	build_project_configured (G_OBJECT (plugin), NULL, NULL, NULL);
 }
 
@@ -2434,7 +2602,7 @@ value_added_fm_current_file (AnjutaPlugin *plugin, const char *name,
 		dirname = g_strdup (filename);
 	else
 		dirname = g_path_get_dirname (filename);
-	makefile_exists = directory_has_makefile (dirname);
+	makefile_exists = directory_has_makefile (dirname) || directory_has_makefile_am (ba_plugin, dirname);
 	g_free (dirname);
 	
 	if (!makefile_exists)
@@ -2498,7 +2666,7 @@ value_added_pm_current_uri (AnjutaPlugin *plugin, const char *name,
 		dirname = g_strdup (filename);
 	else
 		dirname = g_path_get_dirname (filename);
-	makefile_exists = directory_has_makefile (dirname);
+	makefile_exists = directory_has_makefile (dirname) || directory_has_makefile_am (ba_plugin, dirname);
 	g_free (dirname);
 	
 	if (!makefile_exists)
@@ -3003,7 +3171,7 @@ ibuildable_install (IAnjutaBuildable *manager, const gchar *directory,
 {
 	BasicAutotoolsPlugin *plugin = ANJUTA_PLUGIN_BASIC_AUTOTOOLS (manager);
 	
-	build_install_dir (plugin, directory, err);
+	build_install_dir (plugin, directory, NULL, NULL, err);
 }
 
 static void
@@ -3012,7 +3180,7 @@ ibuildable_configure (IAnjutaBuildable *manager, const gchar *directory,
 {
 	BasicAutotoolsPlugin *plugin = ANJUTA_PLUGIN_BASIC_AUTOTOOLS (manager);
 	
-	build_configure_dir (plugin, directory, NULL);
+	build_configure_dir (plugin, directory, NULL, NULL, NULL);
 }
 
 static void
@@ -3021,7 +3189,7 @@ ibuildable_generate (IAnjutaBuildable *manager, const gchar *directory,
 {
 	BasicAutotoolsPlugin *plugin = ANJUTA_PLUGIN_BASIC_AUTOTOOLS (manager);
 
-	build_generate_dir (plugin, directory, NULL);
+	build_generate_dir (plugin, directory, NULL, NULL, NULL);
 }
 
 static void
