@@ -139,7 +139,7 @@ skip_iter_to_newline_tail (IAnjutaIterable *iter, gchar ch)
 /* Jumps to the reverse matching brace of the given brace character */
 
 static gint
-get_line_indentation (IAnjutaEditor *editor, gint line_num, gint* line_indent_spaces)
+get_line_indentation (IAnjutaEditor *editor, gint line_num)
 {
 	IAnjutaIterable *line_begin, *line_end;
 	gchar *line_string, *idx;
@@ -176,9 +176,9 @@ get_line_indentation (IAnjutaEditor *editor, gint line_num, gint* line_indent_sp
 		if (*idx == '\t')
 			line_indent += TAB_SIZE;
 		else
-			line_indent_spaces++;
+			line_indent++;
 		idx++; /* Since we are looking for first non-space char, simple
-	            * increment of the utf8 chars would do */
+				* increment of the utf8 chars would do */
 	}
 	g_free (line_string);
 	return line_indent;
@@ -758,7 +758,7 @@ set_line_indentation (IAnjutaEditor *editor, gint line_num, gint indentation, gi
 	/* If indentation == 0, we really didn't enter the previous code block,
 	 * but we may need to clear existing indentation.
 	 */
-	if (indentation == 0)
+	if ((indentation + line_indent_spaces) == 0)
 	{
 		/* Get existing indentation */
 		if (ianjuta_iterable_compare (indent_position, line_begin, NULL) > 0)
@@ -856,7 +856,7 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 	{
 		/* Continuation of preprocessor line -- just maintain indentation */
 		g_object_unref (iter);
-		return get_line_indentation (editor, line_num - 1, line_indent_spaces);
+		return get_line_indentation (editor, line_num - 1);
 	}
 	else if (current_line_is_preprocessor)
 	{
@@ -1030,7 +1030,7 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 			/* If at level 0 indentation, encoutered a
 			 * block end, don't bother going further
 			 */
-			if (point_ch == '}' && get_line_indentation (editor, line_saved, line_indent_spaces) <= 0)
+			if (point_ch == '}' && get_line_indentation (editor, line_saved) <= 0)
 			{
 				line_indent = 0;
 				line_indent += extra_indent;
@@ -1040,7 +1040,7 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 			/* Find matching brace and continue */
 			if (!cpp_java_util_jump_to_matching_brace (iter, point_ch, -1))
 			{
-				line_indent = get_line_indentation (editor, line_saved, line_indent_spaces);
+				line_indent = get_line_indentation (editor, line_saved);
 				line_indent += extra_indent;
 				break;
 			}
@@ -1049,7 +1049,7 @@ get_line_indentation_base (CppJavaPlugin *plugin,
 		{
 			gint line_for_indent =
 				ianjuta_editor_get_line_from_position (editor, iter, NULL);
-			line_indent = get_line_indentation (editor, line_for_indent, line_indent_spaces);
+			line_indent = get_line_indentation (editor, line_for_indent);
 			/* Increase line indentation */
 			line_indent += INDENT_SIZE;
 			line_indent += extra_indent;
@@ -1218,6 +1218,29 @@ is_iter_inside_string (IAnjutaIterable *iter)
 	return FALSE;
 }
 
+static gboolean
+spaces_only (IAnjutaEditor* editor, IAnjutaIterable* begin, IAnjutaIterable* end)
+{
+	gboolean empty = TRUE;
+	gchar* idx;
+	gchar* text = ianjuta_editor_get_text (editor, begin, end, NULL);
+
+	if (text == NULL)
+		return TRUE;
+	
+
+	for (idx = text; *idx != '\0'; idx++)
+	{
+		if (!isspace(*idx))
+		{
+			empty = FALSE;
+			break;
+		}
+	}
+	g_free(text);
+	return empty;
+}
+
 static gint
 get_line_auto_indentation (CppJavaPlugin *plugin, IAnjutaEditor *editor,
 						   gint line, gint *line_indent_spaces)
@@ -1231,13 +1254,27 @@ get_line_auto_indentation (CppJavaPlugin *plugin, IAnjutaEditor *editor,
 	g_return_val_if_fail (line > 0, 0);
 	
 	if (line == 1) /* First line */
+	{
 		return 0;
+	}
+	else
+	{
+		IAnjutaIterable* begin = ianjuta_editor_get_line_begin_position (editor, line -1 , NULL);
+		IAnjutaIterable* end = ianjuta_editor_get_line_end_position (editor, line -1 , NULL);
+
+		if (spaces_only (editor, begin, end))
+		{
+			set_line_indentation (editor, line -1, 0, 0);
+		}
+		g_object_unref (begin);
+		g_object_unref (end);
+	}
 	
 	iter = ianjuta_editor_get_line_begin_position (editor, line, NULL);
-	
+
 	if (is_iter_inside_string (iter))
 	{
-		line_indent = get_line_indentation (editor, line - 1, line_indent_spaces);
+		line_indent = get_line_indentation (editor, line - 1);
 	}
 	else
 	{
@@ -1246,18 +1283,18 @@ get_line_auto_indentation (CppJavaPlugin *plugin, IAnjutaEditor *editor,
 												 line_indent_spaces,
 												 &colon_indent);
 	}
-	
+
 	if (colon_indent)
 	{
 		/* If the last non-whitespace character in the line is ":" then
 		 * we remove the extra colon_indent
 		 */
-		gchar ch;
 		end_iter = ianjuta_editor_get_line_end_position (editor, line, NULL);
+		gchar ch;
 		while (ianjuta_iterable_previous (end_iter, NULL))
 		{
 			ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (end_iter),
-											   0, NULL);
+			                                   0, NULL);
 			if (ch == ':')
 			{
 				line_indent -= INDENT_SIZE;
@@ -1279,7 +1316,7 @@ get_line_auto_indentation (CppJavaPlugin *plugin, IAnjutaEditor *editor,
 		 */
 		if (is_iter_inside_string (iter))
 		{
-			line_indent = get_line_indentation (editor, line - 1, line_indent_spaces);
+			line_indent = get_line_indentation (editor, line - 1);
 			break;
 		}
 		ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (iter),
@@ -1319,7 +1356,7 @@ get_line_auto_indentation (CppJavaPlugin *plugin, IAnjutaEditor *editor,
 				gint line = ianjuta_editor_get_line_from_position (editor,
 																   iter,
 																   NULL);
-				line_indent = get_line_indentation (editor, line, line_indent_spaces);
+				line_indent = get_line_indentation (editor, line);
 			}
 			break;
 		}
@@ -1412,6 +1449,7 @@ on_editor_char_inserted_cpp (IAnjutaEditor *editor,
 		
 			ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT(editor), NULL);
 			initialize_indentation_params (plugin);
+			
 			insert_line = ianjuta_editor_get_lineno (editor, NULL);
 			line_indent = get_line_auto_indentation (plugin, editor, insert_line, &line_indent_spaces);
 			set_line_indentation (editor, insert_line, line_indent, line_indent_spaces);
@@ -1433,8 +1471,8 @@ on_editor_char_inserted_cpp (IAnjutaEditor *editor,
 			/* If the previous char is a ' we don't have to autocomplete */
 			if (*prev_char != '\'')
 			{
+				
 				ianjuta_iterable_next (iter, NULL);
-		
 				switch (ch)
 				{
 					case '[': ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT (editor), NULL);
@@ -1461,14 +1499,14 @@ on_editor_char_inserted_cpp (IAnjutaEditor *editor,
 		{
 			gchar *prev_char;
 			IAnjutaIterable *previous;
-			
+
 			previous = ianjuta_iterable_clone (iter, NULL);
 			ianjuta_iterable_previous (previous, NULL);
 			prev_char = ianjuta_editor_get_text (editor, previous, iter, NULL);
 
 			/* First iter*/
 			ianjuta_iterable_next (iter, NULL);
-		
+
 			/*
 			 * If the character is " we have to decide if we need insert
 			 * another " or we have to skip the character
