@@ -16,7 +16,6 @@
  */
 
 #include <config.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-plugin.h>
@@ -74,7 +73,7 @@ patch_plugin_activate (AnjutaPlugin *plugin)
 	AnjutaUI *ui;
 	PatchPlugin *p_plugin;
 	
-	DEBUG_PRINT ("PatchPlugin: Activating Patch plugin...");
+	DEBUG_PRINT ("%s", "PatchPlugin: Activating Patch plugin...");
 	
 	p_plugin = ANJUTA_PLUGIN_PATCH (plugin);
 
@@ -105,7 +104,7 @@ static gboolean
 patch_plugin_deactivate (AnjutaPlugin *plugin)
 {
 	AnjutaUI *ui = anjuta_shell_get_ui (plugin->shell, NULL);
-	DEBUG_PRINT ("AnjutaPatchPlugin: Dectivating Patch plugin ...");
+	DEBUG_PRINT ("%s", "AnjutaPatchPlugin: Dectivating Patch plugin ...");
 
 	anjuta_ui_unmerge (ui, ANJUTA_PLUGIN_PATCH (plugin)->uiid);
 
