@@ -59,12 +59,6 @@ GType symbol_db_view_get_type (void) G_GNUC_CONST;
 GtkWidget* 
 symbol_db_view_new (void);
 
-/* return the pixbufs. It will initialize pixbufs first if they weren't before
- * node_access: can be NULL.
- */
-inline const GdkPixbuf*
-symbol_db_view_get_pixbuf  (const gchar *node_type, const gchar *node_access);
-
 void 
 symbol_db_view_open (SymbolDBView *dbv, SymbolDBEngine *dbe);
 
