@@ -498,6 +498,8 @@ anjuta_app_instance_init (AnjutaApp *app)
 	
 	/* Loading accels */
 	anjuta_ui_load_accels (NULL);
+
+	app->save_count = 0;
 }
 
 static void
@@ -768,6 +770,20 @@ anjuta_app_remove_value (AnjutaShell *shell, const char *name, GError **error)
 	}
 }
 
+static void
+anjuta_app_saving_push (AnjutaShell* shell)
+{
+	AnjutaApp* app = ANJUTA_APP (shell);
+	app->save_count++;
+}
+
+static void
+anjuta_app_saving_pop (AnjutaShell* shell)
+{
+	AnjutaApp* app = ANJUTA_APP (shell);
+	app->save_count--;
+}
+
 static gboolean
 remove_from_widgets_hash (gpointer name, gpointer hash_widget, gpointer widget)
 {
@@ -1041,6 +1057,8 @@ anjuta_shell_iface_init (AnjutaShellIface *iface)
 	iface->get_preferences = anjuta_app_get_preferences;
 	iface->get_plugin_manager = anjuta_app_get_plugin_manager;
 	iface->get_profile_manager = anjuta_app_get_profile_manager;
+	iface->saving_push = anjuta_app_saving_push;
+	iface->saving_pop = anjuta_app_saving_pop;
 }
 
 ANJUTA_TYPE_BEGIN(AnjutaApp, anjuta_app, GTK_TYPE_WINDOW);
